<!DOCTYPE html>
<html>
<head>
	<title>{{ title }}</title>
	<meta name="viewport" content="width=device-width, initial-scale=1.0">

	<style type="text/css">
		body {
			font-family: -apple-system, BlinkMacSystemFont, sans-serif;
		}
		h3 {
	    font-weight: 500;
	    margin-bottom: 0;
		}
		.chart {
			max-width: 480px;
		}
	</style>
</head>
<body>
	{% block body %}
	{% endblock %}
</body>
</html>
